function figureH = myMontage(K, figTitle, figH)
% myMontage toimii kuten montage, mutta 
% lisää lukemista helpottavat akselit ja 
% tiedot kuvien määrästä ja suuruudesta.
%
%    figureH = myMontage(K, [figTitle, figH])
% 
%    figureH   kahva luotuun kuvaan, aktivoi "figure(figH)"
%    K         kuvakokoelma muodossa (r x c x 1 x n),
%              katso "help montage"
%    figTitle  valinnainen otsikkorivi, johon lisätään
%              kuvien lkm ja koko
%    figH      kahva olemassa olevaan ikkunaan, johon
%              kuvat halutaan piirretävän
%
% Esimerkki:
%    load 12345A;
%    myMontage(K, 'Alkuperäiset kuvat', 42);

% Jukka Parviainen, parvi@hut.fi, 26.11.2005

if nargin == 0
    error('Liian vähän argumentteja. Katso "help myMontage"');
end;
if nargin <= 2
    figH = figure;
else
    figH = figure(figH); 
    clf;
end;
r        = size(K,1);
c        = size(K,2);
n        = size(K,4);
if nargin == 1
    figTitle = ['Kuva/Fig ' num2str(figH)];
else
    figTitle = [figTitle ' [ n = ' num2str(n) ',  (' num2str(r) ' x ' num2str(c) ') ]'];
end;

MonK = montage(K);
title(figTitle);
MonRows   = size(get(MonK,'CData'),1)/r;
MonCols   = size(get(MonK,'CData'),2)/c;
yTickPos  = round([0.5*r : r : (MonRows-0.5)*r+1]);
xTickPos  = round([0.5*c : c : (MonCols-0.5)*c+1]);
axis on;
set(gca,'XTick',[],'XTickLabel','');
set(gca,'YTick',yTickPos,'YTickLabel',[1 : MonCols : n]);
